#
# spec file for package wl-clipboard-rs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wl-clipboard-rs
Version:        0.8.1
Release:        2.1
Summary:        Wayland Clipboard Utility in Rust
License:        Apache-2.0 AND MIT
URL:            https://github.com/YaLTeR/wl-clipboard-rs
Source0:        https://github.com/YaLTeR/wl-clipboard-rs/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo >= 1.61
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig
BuildRequires:  wayland-devel
BuildRequires:  zstd
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.17
BuildRequires:  pkgconfig(wayland-server) >= 1.16
Recommends:     mailcap
Recommends:     xdg-utils
Conflicts:      wl-clipboard

%description
A safe Rust crate for working with the Wayland clipboard.

%prep
%autosetup -a1

%build
pushd wl-clipboard-rs-tools
CARGO_INCREMENTAL=0 %{cargo_build}

%install
pushd wl-clipboard-rs-tools
CARGO_INCREMENTAL=0 %{cargo_install}

# Removing unnecessary crate related files
find %{buildroot}%{_prefix} -type f \( -name ".crates.toml" -or -name ".crates2.json" \) -delete -print

%files
%{_bindir}/wl-copy
%{_bindir}/wl-paste
%{_bindir}/wl-clip
%license LICENSE-APACHE LICENSE-MIT
%doc README.md CHANGELOG.md doc/index.html

%changelog
* Tue May 21 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Get sources from upstream
- Remove the following files:
  * _servicedata
  * wl-clipboard-rs-0.8.1.obscpio
  * wl-clipboard-rs.obsinfo
  * vendor.tar.gz
- Update vendored dependencies.
- Compression is now zstd so vendored tarball is vendor.tar.zst
- Cleanup specfile
* Mon Mar 18 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 0.8.1:
  * Upgrade dependencies
  * Added copy::Options::omit_additional_text_mime_types to
    disable wl-clipboard-rs offering several known text MIME types
    when a text MIME type is copied.
  * Updated wayland-rs to 0.31. This changed the error types
    slightly. However, most uses of wl-clipboard-rs should be
    completely unaffected.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Thu Jun  8 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies. Resolves bsc#1212012
* Tue Jun  6 2023 Denys Kondratenko <stdden@opensuse.org>
- Update vendor dependencies to fix CVE bnc#1212012
* Tue Sep 27 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for wl-clipboard-rs 0.7.0
